@@ -1,4 +1,5 @@
 use serde::Deserialize;
+use std::collections::HashSet;
 
 use crate::{GCIRResponseFormat, HashAlgorithm};
 
@@ -7,6 +8,11 @@ pub struct ClientInitResponseOptions {
     pub hash_algorithm: Option<HashAlgorithm>,
     pub client_sdk_key: Option<String>,
     pub include_local_overrides: Option<bool>,
+    pub feature_gate_filter: Option<HashSet<String>>,
+    pub experiment_filter: Option<HashSet<String>>,
+    pub dynamic_config_filter: Option<HashSet<String>>,
+    pub layer_filter: Option<HashSet<String>>,
+    pub param_store_filter: Option<HashSet<String>>,
     pub response_format: Option<GCIRResponseFormat>,
 }
 
