@@ -1,7 +1,9 @@
 mod http_types;
 mod network_client;
+pub mod network_error;
 pub mod providers;
 pub mod proxy_config;
 
 pub use http_types::*;
 pub use network_client::*;
+pub use network_error::*;
