@@ -2,23 +2,22 @@ mod utils;
 
 use crate::utils::mock_specs_adapter::MockSpecsAdapter;
 use lazy_static::lazy_static;
-use statsig_rust::{dyn_value, Statsig, StatsigOptions, StatsigUser};
+use statsig_rust::{dyn_value, Statsig, StatsigOptions, StatsigUser, StatsigUserBuilder};
 use std::collections::HashMap;
 use std::sync::Arc;
 use std::time::Instant;
 
 lazy_static! {
-    static ref USER: StatsigUser = StatsigUser {
-        custom: Some(HashMap::from([
-            ("flavor".to_string(), dyn_value!("chocolate")),
-            ("region".to_string(), dyn_value!("somewhere")),
-            ("service".to_string(), dyn_value!("some-service")),
-        ])),
-        ..StatsigUser::with_custom_ids(HashMap::from([(
-            "hubID".to_string(),
-            "some-service-123".to_string()
-        )]))
-    };
+    static ref USER: StatsigUser = StatsigUserBuilder::new_with_custom_ids(HashMap::from([(
+        "hubID".to_string(),
+        "some-service-123".to_string()
+    )]))
+    .custom(Some(HashMap::from([
+        ("flavor".to_string(), dyn_value!("chocolate")),
+        ("region".to_string(), dyn_value!("somewhere")),
+        ("service".to_string(), dyn_value!("some-service")),
+    ])))
+    .build();
 }
 
 const SDK_KEY: &str = "secret-key";
